@@ -84,6 +84,7 @@ from anyscale.sdk.anyscale_client.models import (
     CreateClusterEnvironment,
     CreateClusterEnvironmentBuild,
     Job as APIJobRun,
+    ProductionServiceV2VersionModel,
     Project,
     RollbackServiceModel,
     ServiceModel,
@@ -1159,15 +1160,59 @@ class AnyscaleClient(AnyscaleClientInterface):
 
         return all_log_chunk_urls, bearer_token
 
+    def _fetch_log_chunks_for_controller_logs(
+        self, cluster_id: str
+    ) -> Tuple[List[str], Any]:
+        all_log_chunk_urls = []
+        MAX_PAGE_SIZE = 1000
+        next_page_token = None
+        bearer_token = None
+        while True:
+            log_download_result = self._internal_api_client.get_serve_logs_download_api_v2_logs_serve_logs_download_cluster_id_get(
+                cluster_id=cluster_id,
+                next_page_token=next_page_token,
+                page_size=MAX_PAGE_SIZE,
+            ).result
+
+            if bearer_token is None:
+                bearer_token = log_download_result.bearer_token
+
+            all_log_chunk_urls.extend(
+                [chunk.chunk_url for chunk in log_download_result.log_chunks]
+            )
+
+            next_page_token = log_download_result.next_page_token
+            if next_page_token is None:
+                break
+
+        return all_log_chunk_urls, bearer_token
+
     def _read_log_lines(
         self,
         log_chunk_urls: List[str],
         head: bool,
         bearer_token: Any,
         max_lines: Optional[int],
+        parse_json: Optional[bool] = None,
     ) -> str:
         # TODO(mowen): Would be nice to return some placeholder here to allow all new
         # logs to be read from a particular point onwards.
+        # TODO(aguo): Change this to be a generator to avoid loading all logs into memory at once
+        # and to gradually load logs as needed.
+
+        def parse_json_line(line: str) -> str:
+            json_line = json.loads(line)
+            # This is the default schema for ray core logger but users
+            # could technically use any schema they want for structured logs.
+            # Fall back to spitting out the json in the worst-case scenario.
+            if "asctime" in json_line and "message" in json_line:
+                return f"{json_line['asctime']} {json_line['message']}"
+            elif "message" in json_line:
+                return json_line["message"]
+            # This is the worst-case scenario but very unlikely. Users would
+            # not likely be changing "message" to something-else.
+            return line
+
         result_lines: List[str] = []
         step = 1 if head else -1
         line_count = 0
@@ -1177,15 +1222,32 @@ class AnyscaleClient(AnyscaleClientInterface):
             ).splitlines()
 
             if max_lines is not None:
-                lines_to_add = min(len(log_lines), max_lines - line_count)
+                num_lines_to_add = min(len(log_lines), max_lines - line_count)
             else:
-                lines_to_add = len(log_lines)
-            line_count += lines_to_add
+                num_lines_to_add = len(log_lines)
+            line_count += num_lines_to_add
 
             if head:
-                result_lines = result_lines + log_lines[:lines_to_add]
+                lines_to_add = log_lines[:num_lines_to_add]
             else:
-                result_lines = log_lines[-1 * lines_to_add :] + result_lines
+                lines_to_add = log_lines[-1 * num_lines_to_add :]
+
+            if parse_json is not False:
+                try:
+                    lines_to_add = [parse_json_line(line) for line in lines_to_add]
+                except json.JSONDecodeError:
+                    if parse_json is True:
+                        raise ValueError(
+                            "Failed to parse logs as JSON. Logs are not all in JSON format."
+                        )
+                    # If we fail to parse_json, we should always just use plain text going forward.
+                    parse_json = False
+                    # lines_to_add should already be plain text, so continue on...
+
+            if head:
+                result_lines = result_lines + lines_to_add
+            else:
+                result_lines = lines_to_add + result_lines
 
             if line_count == max_lines:
                 break
@@ -1194,13 +1256,74 @@ class AnyscaleClient(AnyscaleClientInterface):
 
     @handle_api_exceptions
     def logs_for_job_run(
-        self, job_run_id: str, head: bool = False, max_lines: Optional[int] = None
+        self,
+        job_run_id: str,
+        head: bool = False,
+        max_lines: Optional[int] = None,
+        parse_json: Optional[bool] = None,
     ) -> str:
-        """Retrieves logs from the streaming job logs folder in S3/GCS"""
+        """
+        Retrieves logs from the streaming job logs folder in S3/GCS
+        Args:
+        - parse_json: If true, we will always attempt to parse the logs as JSON.
+            If false, we will always attempt to parse the logs as text. If None, we
+            will attempt to parse the logs as JSON and fall back to text if parsing
+            fails.
+        """
 
         all_log_chunk_urls, bearer_token = self._fetch_log_chunks(job_run_id)
 
-        logs = self._read_log_lines(all_log_chunk_urls, head, bearer_token, max_lines)
+        logs = self._read_log_lines(
+            all_log_chunk_urls, head, bearer_token, max_lines, parse_json=parse_json
+        )
+        return logs
+
+    @handle_api_exceptions
+    def controller_logs_for_service_version(
+        self,
+        service_version: ProductionServiceV2VersionModel,
+        head: bool = False,
+        max_lines: Optional[int] = None,
+        parse_json: Optional[bool] = None,
+    ) -> str:
+        """
+        Returns the controller logs associated with a particular service version.
+
+        Args:
+        - parse_json: If true, we will always attempt to parse the logs as JSON.
+            If false, we will always attempt to parse the logs as text. If None, we
+            will attempt to parse the logs as JSON and fall back to text if parsing
+            fails.
+        """
+        service_version_id = service_version.id[-8:]
+        if not len(service_version.production_job_ids):
+            raise ValueError(
+                f"Service version '{service_version_id}' canary version is not ready. Please try again later..."
+            )
+
+        job = self._internal_api_client.get_job_api_v2_decorated_ha_jobs_production_job_id_get(
+            service_version.production_job_ids[0]
+        ).result
+
+        if not job:
+            raise ValueError(
+                f"Service version '{service_version_id}' canary version is not ready. Please try again later..."
+            )
+
+        if not job.state.cluster:
+            raise ValueError(
+                f"Service version '{service_version_id}' canary version is not ready. Please try again later..."
+            )
+
+        cluster_id = job.state.cluster.id
+
+        all_log_chunk_urls, bearer_token = self._fetch_log_chunks_for_controller_logs(
+            cluster_id
+        )
+
+        logs = self._read_log_lines(
+            all_log_chunk_urls, head, bearer_token, max_lines, parse_json=parse_json
+        )
         return logs
 
     @handle_api_exceptions
