@@ -25,6 +25,7 @@ from anyscale.sdk.anyscale_client.models import (
     ClusterCompute,
     ClusterEnvironment,
     Job as APIJobRun,
+    ProductionServiceV2VersionModel,
     ServiceModel,
 )
 from anyscale.sdk.anyscale_client.models.cluster_environment_build import (
@@ -370,10 +371,36 @@ class AnyscaleClientInterface(ABC):
         head: bool = False,
         tail: bool = True,
         max_lines: Optional[int] = None,
+        parse_json: Optional[bool] = None,
     ) -> str:
         """Returns the logs associated with a particular job run.
 
         The job_run_id is the backend id for the job run.
+
+        Args:
+        - parse_json: If true, we will always attempt to parse the logs as JSON.
+            If false, we will always attempt to parse the logs as text. If None, we
+            will attempt to parse the logs as JSON and fall back to text if parsing
+            fails.
+        """
+        raise NotImplementedError
+
+    @abstractmethod
+    def controller_logs_for_service_version(
+        self,
+        service_version: ProductionServiceV2VersionModel,
+        head: bool = False,
+        max_lines: Optional[int] = None,
+        parse_json: Optional[bool] = None,
+    ) -> str:
+        """
+        Returns the controller logs associated with a particular service version.
+
+        Args:
+        - parse_json: If true, we will always attempt to parse the logs as JSON.
+            If false, we will always attempt to parse the logs as text. If None, we
+            will attempt to parse the logs as JSON and fall back to text if parsing
+            fails.
         """
         raise NotImplementedError
 
