@@ -142,6 +142,7 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
         self._submitted_job: Optional[CreateInternalProductionJob] = None
         self._env_vars: Optional[Dict[str, str]] = None
         self._job_run_logs: Dict[str, str] = {}
+        self._controller_logs: Dict[str, str] = {}
         self._schedules: Dict[str, DecoratedSchedule] = {}
         self._schedule_trigger_counts: Dict[str, int] = defaultdict(int)
         self._workspaces: Dict[str, ExperimentalWorkspace] = {}
@@ -753,7 +754,9 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
         self,
         job_run_id: str,
         head: bool = False,  # noqa: ARG002
+        tail: bool = True,  # noqa: ARG002
         max_lines: Optional[int] = None,  # noqa: ARG002
+        parse_json: Optional[bool] = None,  # noqa: ARG002
     ) -> str:
         log_lines = self._job_run_logs.get(job_run_id, "").splitlines()
         if max_lines is None:
@@ -763,6 +766,24 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
         else:
             return "\n".join(log_lines[-1 * max_lines :])
 
+    def add_controller_logs(self, service_version_id: str, logs: str):
+        self._controller_logs[service_version_id] = logs
+
+    def controller_logs_for_service_version(
+        self,
+        service_version: ProductionServiceV2VersionModel,
+        head: bool = False,
+        max_lines: Optional[int] = None,
+        parse_json: Optional[bool] = None,  # noqa: ARG002
+    ) -> str:
+        log_lines = self._controller_logs.get(service_version.id, "").splitlines()
+        if max_lines is None:
+            max_lines = len(log_lines)
+        if head:
+            return "\n".join(log_lines[:max_lines])
+        else:
+            return "\n".join(log_lines[-1 * max_lines :])
+
     def get_schedule(
         self,
         *,
