@@ -83,7 +83,7 @@ AWS_RESOURCE_DICT: Dict[str, CloudAnalyticsEventCloudResource] = {
 def log_resource_not_found_error(
     resource_name: str, resource_id: str, logger: CloudSetupLogger
 ) -> None:
-    resource = AWS_RESOURCE_DICT.get(resource_name, None)
+    resource = AWS_RESOURCE_DICT.get(resource_name)
     if resource:
         logger.log_resource_error(resource, CloudSetupError.RESOURCE_NOT_FOUND)
     logger.error(
