@@ -551,12 +551,6 @@ def cloud_config_update(
     required=False,
     type=str,
 )
-@click.option(
-    "--kubernetes-ingress-external-address",
-    help="On the Kubernetes compute stack, the address of the ingress used for serving traffic for Anyscale services.",
-    required=False,
-    type=str,
-)
 @click.option(
     "--kubernetes-zones",
     help="On the Kubernetes compute stack, a comma-separated list of zones to launch pods in.",
@@ -630,7 +624,6 @@ def register_cloud(  # noqa: PLR0913, PLR0912
     nfs_mount_path: str,
     memorystore_instance_name: str,
     host_project_id: Optional[str],
-    kubernetes_ingress_external_address: Optional[str],
     kubernetes_zones: Optional[str],
     anyscale_operator_iam_identity: Optional[str],
     functional_verify: Optional[str],
@@ -656,11 +649,6 @@ def register_cloud(  # noqa: PLR0913, PLR0912
             (instance_iam_role_id, "--instance-iam-role-id", (ComputeStack.VM)),
             (security_group_ids, "--security-group-ids", (ComputeStack.VM)),
             (s3_bucket_id, "--s3-bucket-id", (ComputeStack.VM, ComputeStack.K8S)),
-            (
-                kubernetes_ingress_external_address,
-                "--kubernetes-ingress-external-address",
-                (ComputeStack.K8S),
-            ),
             (kubernetes_zones, "--kubernetes-zones", (ComputeStack.K8S)),
             (
                 anyscale_operator_iam_identity,
@@ -689,7 +677,6 @@ def register_cloud(  # noqa: PLR0913, PLR0912
             s3_bucket_id=s3_bucket_id,
             memorydb_cluster_id=memorydb_cluster_id,
             functional_verify=functional_verify,
-            kubernetes_ingress_external_address=kubernetes_ingress_external_address,
             kubernetes_zones=kubernetes_zones.split(",") if kubernetes_zones else [],
             anyscale_operator_iam_identity=anyscale_operator_iam_identity,
             private_network=private_network,
@@ -726,11 +713,6 @@ def register_cloud(  # noqa: PLR0913, PLR0912
                 "--cloud-storage-bucket-name",
                 (ComputeStack.VM, ComputeStack.K8S),
             ),
-            (
-                kubernetes_ingress_external_address,
-                "--kubernetes-ingress-external-address",
-                (ComputeStack.K8S),
-            ),
             (kubernetes_zones, "--kubernetes-zones", (ComputeStack.K8S)),
             (
                 anyscale_operator_iam_identity,
@@ -796,7 +778,6 @@ def register_cloud(  # noqa: PLR0913, PLR0912
             cloud_storage_bucket_name=cloud_storage_bucket_name,
             memorystore_instance_name=memorystore_instance_name,
             host_project_id=host_project_id,
-            kubernetes_ingress_external_address=kubernetes_ingress_external_address,
             kubernetes_zones=kubernetes_zones.split(",") if kubernetes_zones else [],
             anyscale_operator_iam_identity=anyscale_operator_iam_identity,
             functional_verify=functional_verify,
@@ -824,7 +805,6 @@ def register_cloud(  # noqa: PLR0913, PLR0912
             cloud_storage_bucket_endpoint=cloud_storage_bucket_endpoint,
             nfs_mount_targets=list(nfs_mount_target) if nfs_mount_target else [],
             nfs_mount_path=nfs_mount_path,
-            kubernetes_ingress_external_address=kubernetes_ingress_external_address,
             kubernetes_zones=kubernetes_zones.split(",") if kubernetes_zones else [],
         )
 
