@@ -323,6 +323,14 @@ Download complete!
 {"messages":[{"content":"bye","role":"user"},{"content":"Goodbye!","role":"assistant"}]}
 """
 
+LLM_DATASET_LIST_EXAMPLE = """
+$ anyscale llm dataset list
+ID         Name                   Description                       Created At             Num Versions
+---------  ---------------------  --------------------------------  -------------------  --------------
+dataset_2  second                 second upload                     1/2/2024 12:00 PM              23
+dataset_1  first                  first upload                      1/1/2024 12:00 PM              13
+"""
+
 RESOURCE_QUOTAS_CREATE_EXAMPLE = """
 $ anyscale resource-quota create -n my-resource-quota --cloud my-cloud --project my-project --user-email someone@myorg.com --num-instances 100 --num-cpus 1000 --num-gpus 50 --num-accelerators A10G 10 --num-accelerators A100-80G 0
 (anyscale +2.5s) Name: my-resource-quota
