@@ -11,7 +11,11 @@ import anyscale
 from anyscale._private.models.image_uri import ImageURI
 from anyscale.cli_logger import BlockLogger
 from anyscale.commands import command_examples
-from anyscale.commands.util import AnyscaleCommand, convert_kv_strings_to_dict
+from anyscale.commands.util import (
+    AnyscaleCommand,
+    convert_kv_strings_to_dict,
+    override_env_vars,
+)
 from anyscale.controllers.job_controller import JobController
 from anyscale.job.models import JobConfig, JobLogMode, JobState, JobStatus
 from anyscale.util import validate_non_negative_arg
@@ -98,7 +102,7 @@ def job_cli() -> None:
     required=False,
     default=None,
     type=str,
-    help="Path to a local directory that will be the working directory for the job. The files in the directory will be automatically uploaded to cloud storage. When running in a workspace, this defaults to the current working directory.",
+    help="Path to a local directory or a remote URI to a .zip file (S3, GS, HTTP) that will be the working directory for the job. The files in the directory will be automatically uploaded to cloud storage. When running in a workspace, this defaults to the current working directory.",
 )
 @click.option(
     "-e",
@@ -310,9 +314,8 @@ and override the entrypoint with `python main.py`.
             config = config.options(requirements=requirements)
 
         if env:
-            env_dict = convert_kv_strings_to_dict(env)
-            if env_dict:
-                config = config.options(env_vars=env_dict)
+            config = override_env_vars(config, convert_kv_strings_to_dict(env))
+
         if py_module:
             for module in py_module:
                 if not pathlib.Path(module).is_dir():
