@@ -30,9 +30,19 @@ def machine_pool_cli() -> None:
     required=True,
     help="Provide a machine pool name (must be unique within an organization).",
 )
-def create_machine_pool(name: str) -> None:
+@click.option(
+    "--enable-rootless-dataplane-config",
+    type=bool,
+    default=False,
+    required=False,
+    help="Enable the dataplane rootless configuration for nodes running under this machine pool.",
+)
+def create_machine_pool(name: str, enable_rootless_dataplane_config: bool) -> None:
     machine_pool_controller = MachinePoolController()
-    output = machine_pool_controller.create_machine_pool(machine_pool_name=name)
+    output = machine_pool_controller.create_machine_pool(
+        machine_pool_name=name,
+        enable_rootless_dataplane_config=enable_rootless_dataplane_config,
+    )
     print(
         f"Machine pool {output.machine_pool.machine_pool_name} has been created successfully (ID {output.machine_pool.machine_pool_id})."
     )
@@ -67,10 +77,16 @@ def list_machine_pools() -> None:
         "MACHINE POOL",
         "ID",
         "Clouds",
+        "Rootless",
     ]
     for mp in output.machine_pools:
         table.append(
-            [mp.machine_pool_name, mp.machine_pool_id, "\n".join(mp.cloud_ids),]
+            [
+                mp.machine_pool_name,
+                mp.machine_pool_id,
+                "\n".join(mp.cloud_ids),
+                mp.enable_rootless_dataplane_config,
+            ]
         )
     print(tabulate.tabulate(table, tablefmt="plain", headers=columns, stralign="left"))
 
