@@ -16,7 +16,7 @@ from anyscale.commands.util import (
 )
 from anyscale.controllers.service_controller import ServiceController
 import anyscale.service
-from anyscale.service import ServiceConfig, ServiceState, ServiceStatus
+from anyscale.service import ServiceConfig, ServiceLogMode, ServiceState, ServiceStatus
 from anyscale.util import validate_non_negative_arg
 
 
@@ -466,6 +466,77 @@ def wait(
     )
 
 
+# This is a private CLI command to be used internally for testing. This is HIDDEN
+# from the user and is not documented in the CLI help.
+@service_cli.command(
+    name="controller-logs", help="View the controller logs of a service.", hidden=True,
+)
+@click.option(
+    "-n", "--name", required=True, type=str, help="Name of the service.",
+)
+@click.option(
+    "--cloud",
+    required=False,
+    default=None,
+    type=str,
+    help="The Anyscale Cloud to run this workload on. If not provided, the organization default will be used (or, if running in a workspace, the cloud of the workspace).",
+)
+@click.option(
+    "--project",
+    required=False,
+    default=None,
+    type=str,
+    help="Named project to use for the service. If not provided, the default project for the cloud will be used (or, if running in a workspace, the project of the workspace).",
+)
+@click.option(
+    "--canary",
+    required=False,
+    default=False,
+    type=bool,
+    is_flag=True,
+    help="Whether to show the logs of the canary version of the service. If not provided, the primary version logs will be shown.",
+)
+@click.option(
+    "--head",
+    required=False,
+    default=False,
+    type=bool,
+    is_flag=True,
+    help="Used with --max-lines to get `max-lines` lines from the head of the log.",
+)
+@click.option(
+    "--max-lines",
+    required=False,
+    default=1000,
+    type=int,
+    help="Used with --head to limit the number of lines output.",
+)
+def controller_logs(
+    name: str,
+    cloud: Optional[str],
+    project: Optional[str],
+    canary: bool,
+    head: bool,
+    max_lines: int = 1000,
+):
+    mode = ServiceLogMode.TAIL
+    if head:
+        mode = ServiceLogMode.HEAD
+
+    try:
+        logs = anyscale.service._controller_logs(  # noqa: SLF001
+            name=name,
+            cloud=cloud,
+            project=project,
+            canary=canary,
+            mode=mode,
+            max_lines=max_lines,
+        )
+        print(logs)
+    except ValueError as e:
+        raise click.ClickException(str(e))
+
+
 @service_cli.command(
     name="rollout",
     help="Roll out a service.",
