@@ -266,7 +266,6 @@ class ClientBuilder:
         self._user_runtime_env: Dict[str, Any] = {}
         self._allow_public_internet_traffic: Optional[bool] = None
         self._ray_init_kwargs: Dict[str, Any] = {}
-        self._cluster_compute_version: Optional[int] = None
         # Override default run mode.
         if "ANYSCALE_LOCAL_DOCKER" in os.environ:
             self._run_mode = "local_docker"
@@ -482,11 +481,10 @@ class ClientBuilder:
                 self.autosuspend(enabled=False)
             else:
                 self.autosuspend(minutes=int(value))
+        elif value == -1:  # Setting autosuspend to -1 disables it.
+            self.autosuspend(enabled=False)
         else:
-            if value == -1:  # Setting autosuspend to -1 disables it.
-                self.autosuspend(enabled=False)
-            else:
-                self.autosuspend(minutes=value)
+            self.autosuspend(minutes=value)
 
     def _parse_arg_as_method(self, argument_name: str, argument_value: Any) -> bool:
         """
@@ -730,14 +728,6 @@ class ClientBuilder:
         if cluster_compute_unset:
             self._fill_config_from_env("cluster_compute")
 
-        # Only fill cluster_compute from environment if neither a name nor
-        # a dict was passed
-        cluster_compute_version_unset = (
-            self._cluster_compute_version is None and self._cluster_compute_dict is None
-        )
-        if cluster_compute_version_unset:
-            self._fill_config_from_env("cluster_compute_version")
-
         # Only fill cluster_env if neither a name nor a dict was passed
         cluster_env_unset = (
             self._cluster_env_name is None and self._cluster_env_dict is None
@@ -885,7 +875,6 @@ class ClientBuilder:
             cluster_env_dict=self._cluster_env_dict,
             cluster_env_revision=self._cluster_env_revision,
             ray=self._ray,
-            cluster_compute_version=self._cluster_compute_version,
         )
         cluster_name = self._prepare_cluster_block.cluster_name
 
