@@ -1,3 +1,4 @@
+import contextlib
 import inspect
 import json
 import logging
@@ -50,14 +51,14 @@ class StartInteractiveSessionBlock:
     StartInteractiveSessionBlock object is correctly created.
     """
 
-    def __init__(
+    def __init__(  # noqa: PLR0913
         self,
         cluster: Session,
         job_config: Any,
         allow_multiple_clients: bool,
         initial_scale: INITIAL_SCALE_TYPE,
         in_shell: bool,
-        run_mode: Optional[str],
+        run_mode: Optional[str],  # noqa: ARG002
         ray_init_kwargs: RAY_INIT_KWARGS_DICT_TYPE,
         secure: bool,
         ignore_version_check: bool,
@@ -100,7 +101,7 @@ class StartInteractiveSessionBlock:
 
         # Issue request resources call.
         if initial_scale:
-            self.log.debug("Calling request_resources({})".format(initial_scale))
+            self.log.debug(f"Calling request_resources({initial_scale})")
             self._ray.autoscaler.sdk.request_resources(bundles=initial_scale)
 
         # Define ray in the notebook automatically for convenience.
@@ -109,7 +110,7 @@ class StartInteractiveSessionBlock:
             if in_shell and fr is not None and "ray" not in fr.frame.f_globals:
                 self.log.debug("Auto importing Ray into the notebook.")
                 fr.frame.f_globals["ray"] = self._ray
-        except Exception as e:
+        except Exception as e:  # noqa: BLE001
             raise RuntimeError("Failed to auto define `ray` in notebook", e)
 
         self.anyscale_client_context = AnyscaleClientContext(
@@ -209,7 +210,7 @@ class StartInteractiveSessionBlock:
                 block_label=self.block_label,
             )
 
-    def _acquire_session_lock(
+    def _acquire_session_lock(  # noqa: PLR0913
         self,
         session_meta: Session,
         connection_retries: int,
@@ -276,9 +277,7 @@ class StartInteractiveSessionBlock:
             info = self._ray.util.connect(session_url, **connect_kwargs)
             self.log.debug("Connected server info: ", info)
         except Exception as connection_exception:
-            self.log.debug(
-                "Connection error after {} retries".format(connection_retries)
-            )
+            self.log.debug(f"Connection error after {connection_retries} retries")
             ray_info = None
             try:
                 self.log.info(
@@ -302,7 +301,7 @@ class StartInteractiveSessionBlock:
                 re_match = re.search("{.*}", output.decode())
                 if re_match:
                     ray_info = json.loads(re_match.group(0))
-            except Exception as inner_exception:
+            except Exception as inner_exception:  # noqa: BLE001
                 self.log.debug(f"Failed to get debug info: {inner_exception}")
 
             if ray_info is not None:
@@ -388,11 +387,10 @@ class StartInteractiveSessionBlock:
             )
         )
         host_name = None
-        try:
+        with contextlib.suppress(AttributeError):
             host_name = cluster.host_name
             # like "https://session-fqsx0p3pzfna71xxxxxxx.anyscaleuserdata.com"
-        except AttributeError:
-            pass
+
         if not host_name:
             jupyter_notebook_url = cluster.jupyter_notebook_url
             if jupyter_notebook_url:
@@ -401,10 +399,10 @@ class StartInteractiveSessionBlock:
                     jupyter_notebook_url.split("/")[2].lower()
                 )
         if host_name:
-            self.log.debug("URL for head node of cluster: {}".format(host_name))
+            self.log.debug(f"URL for head node of cluster: {host_name}")
 
 
-def start_interactive_session_block(
+def start_interactive_session_block(  # noqa: PLR0913
     cluster: Session,
     job_config: Any,
     allow_multiple_clients: bool,
