@@ -51,7 +51,7 @@ def run_command_on_all_nodes(command: str, timeout: Optional[float]):
             try:
                 # TODO(mattweber): Once the publicly named run_kill_child is
                 # available on product nodes, remove the underscore on this function.
-                _run_kill_child(command, shell=True, check=True, env=env)  # noqa
+                _run_kill_child(command, shell=True, check=True, env=env)
             finally:
                 # allow time for any logs to propogate before the task exits
                 time.sleep(1)
@@ -121,7 +121,7 @@ class ConfigController(BaseController):
             {"name": name, "config": cluster_compute_config, "anonymous": anonymous}
         )
 
-    def setup_dev_ray(  # noqa: PLR0913
+    def setup_dev_ray(
         self,
         working_dir: str,
         cluster_name: str,
@@ -408,7 +408,7 @@ def run_kill_child(
 
         try:
             stdout, stderr = process.communicate(input, timeout=timeout)
-        except:  # noqa      (this is taken from subprocess.run directly)
+        except:
             # Including KeyboardInterrupt, communicate handled that.
             process.kill()
             # We don't call process.wait() as .__exit__ does that for us.
