@@ -117,7 +117,7 @@ class ProjectController(BaseController):
             message = (
                 "Warning: `anyscale init` is no longer accepting a cluster yaml in "
                 "the --config argument. All sessions should be started with cluster envs "
-                "and cluster computes."
+                "and compute configs."
             )
             self.log.warning(message)
         project_id_path = anyscale.project.ANYSCALE_PROJECT_FILE
