@@ -16,11 +16,11 @@ class LLMSDK(BaseSDK):
         client: Optional[AnyscaleClientInterface] = None,
         timer: Optional[Timer] = None,
     ):
-        self._models = LLMModelsSDK(logger=logger, client=client, timer=timer)
+        self._model = LLMModelsSDK(logger=logger, client=client, timer=timer)
 
     @property
-    def models(self):
-        return self._models
+    def model(self):
+        return self._model
 
     @property
     def dataset(self):
