@@ -11,7 +11,6 @@ from anyscale.anyscale_pydantic import (
     Extra,
     Field,
     root_validator,
-    validator,
 )
 from anyscale.cli_logger import LogsLogger
 from anyscale.cluster_compute import (
@@ -309,25 +308,12 @@ class BaseHAJobConfig(BaseModel):
         5,
         description="The number of retries this job will attempt on failure. Set to None to set infinite retries",
     )
-    compute_config_version: Optional[int] = Field(
-        None,
-        description="The compute config version filter that you want to use. Only applicable if the compute_config was specified by name. "
-        "Versions are positive integers. "
-        "Setting version to None is equivalent to setting version to latest version.",
-    )
 
     job_queue_config: Optional[Dict[str, Any]] = Field(
         None,
         description="Configuration specifying semantic of the execution using job queues",
     )
 
-    @validator("compute_config_version")
-    def optional_positive_int(cls, v):
-        assert (
-            v is None or v >= 1
-        ), "compute_config_version must be a positive integer or None"
-        return v
-
     class Config:
         extra = Extra.forbid
 
@@ -402,11 +388,10 @@ class BaseHAJobConfig(BaseModel):
 
     @root_validator
     def fill_compute_config_id(cls: Any, values: Any) -> Any:
-        compute_config_id, compute_config, cloud, compute_config_version = (
+        compute_config_id, compute_config, cloud = (
             values.get("compute_config_id"),
             values.get("compute_config"),
             values.get("cloud"),
-            values.get("compute_config_version"),
         )
         project_id = values.get("project_id")
         if not project_id:
@@ -418,9 +403,7 @@ class BaseHAJobConfig(BaseModel):
                 "Only one of `compute_config_id`, `compute_config`, or `cloud` can be provided in the config file."
             )
         if compute_config and isinstance(compute_config, str):
-            compute_config_id = get_cluster_compute_from_name(
-                compute_config, version=compute_config_version
-            ).id
+            compute_config_id = get_cluster_compute_from_name(compute_config).id
         elif compute_config and isinstance(compute_config, dict):
             compute_config_id = register_compute_template(compute_config).id
         elif cloud:
