@@ -17,19 +17,23 @@ from anyscale.commands.exec_commands import anyscale_exec
 from anyscale.commands.experimental_integrations_commands import (
     experimental_integrations_cli,
 )
-from anyscale.commands.fine_tune_commands import fine_tune_cli
+from anyscale.commands.image_commands import image_cli
 from anyscale.commands.job_commands import job_cli
 from anyscale.commands.list_commands import list_cli
+from anyscale.commands.llm.group import llm_cli
 from anyscale.commands.login_commands import anyscale_login, anyscale_logout
 from anyscale.commands.logs_commands import log_cli
 from anyscale.commands.machine_commands import machine_cli
 from anyscale.commands.machine_pool_commands import machine_pool_cli
 from anyscale.commands.migrate_commands import migrate_cli
 from anyscale.commands.project_commands import anyscale_init, project_cli
+from anyscale.commands.resource_quota_commands import resource_quota_cli
 from anyscale.commands.schedule_commands import schedule_cli
+from anyscale.commands.service_account_commands import service_account_cli
 from anyscale.commands.service_commands import service_cli
 from anyscale.commands.session_commands_hidden import session_cli
 from anyscale.commands.workspace_commands import workspace_cli
+from anyscale.commands.workspace_commands_v2 import workspace_cli as workspace_cli_v2
 import anyscale.conf
 from anyscale.utils.cli_version_check_util import log_warning_if_version_needs_upgrade
 
@@ -113,14 +117,16 @@ cli.add_command(schedule_cli)
 cli.add_command(service_cli)
 cli.add_command(cluster_cli)
 cli.add_command(workspace_cli)
+cli.add_command(workspace_cli_v2)
 cli.add_command(experimental_integrations_cli)
 cli.add_command(auth_cli)
-cli.add_command(fine_tune_cli)
+cli.add_command(llm_cli)
 
 cli.add_command(anyscale_init)
 cli.add_command(anyscale_exec)
 cli.add_command(anyscale_help)
 cli.add_command(compute_config_cli)
+cli.add_command(image_cli)
 
 # Commands to interact with the Anyscale API
 cli.add_command(anyscale_api)
@@ -130,6 +136,8 @@ cli.add_command(anyscale_login)
 cli.add_command(anyscale_logout)
 cli.add_command(machine_cli)
 cli.add_command(machine_pool_cli)
+cli.add_command(service_account_cli)
+cli.add_command(resource_quota_cli)
 
 ALIASES = {
     "h": anyscale_help,
@@ -137,6 +145,8 @@ ALIASES = {
     "jobs": job_cli,
     "services": service_cli,
     "cluster-compute": compute_config_cli,
+    "images": image_cli,
+    "sa": service_account_cli,
 }
 
 
