@@ -147,6 +147,7 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
         api_client.set_default_header(RequestHeaders.CLIENT_VERSION, version)
 
         self.log: BlockLogger = BlockLogger()
+        self._auth_token = auth_token
 
         super(AnyscaleSDK, self).__init__(api_client)
 
@@ -540,7 +541,7 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
                 (so far, if the job is still running)
         """
         string_logger = StringLogger()
-        job_controller = JobController(string_logger)
+        job_controller = JobController(string_logger, auth_token=self._auth_token)
         job_controller.logs(job_id, no_cluster_journal_events=True)
 
         return string_logger.out_string
