@@ -1,5 +1,5 @@
 import copy
-from typing import Any, Dict, Optional
+from typing import Any, Dict, Optional, Union
 
 from anyscale._private.workload import WorkloadSDK
 from anyscale.compute_config.models import ComputeConfig
@@ -18,6 +18,7 @@ from anyscale.sdk.anyscale_client.models import (
 from anyscale.service.models import (
     RayGCSExternalStorageConfig,
     ServiceConfig,
+    ServiceLogMode,
     ServiceState,
     ServiceStatus,
     ServiceVersionStatus,
@@ -667,3 +668,35 @@ class PrivateServiceSDK(WorkloadSDK):
             raise TimeoutError(
                 f"Service '{name}' did not reach target state {state} within {timeout_s}s. Last seen state: {curr_state}."
             )
+
+    def controller_logs(
+        self,
+        name: str,
+        *,
+        cloud: Optional[str] = None,
+        project: Optional[str] = None,
+        canary: bool = False,
+        mode: Union[str, ServiceLogMode] = ServiceLogMode.TAIL,
+        max_lines: int = 1000,
+    ) -> str:
+        model = self._resolve_to_service_model(name=name, cloud=cloud, project=project)
+        head = mode == ServiceLogMode.HEAD
+
+        if canary:
+            if model.canary_version is None:
+                raise ValueError(
+                    f"Service '{name}' is not currently rolling out. There is no canary version."
+                )
+
+            return self.client.controller_logs_for_service_version(
+                model.canary_version, head, max_lines
+            )
+
+        if model.primary_version is None:
+            raise ValueError(
+                f"Service '{name}' is not ready yet. Please try again later..."
+            )
+
+        return self.client.controller_logs_for_service_version(
+            model.primary_version, head, max_lines
+        )
