@@ -2,7 +2,12 @@ from typing import Optional, Union
 
 from anyscale._private.sdk import sdk_command
 from anyscale.service._private.service_sdk import PrivateServiceSDK
-from anyscale.service.models import ServiceConfig, ServiceState, ServiceStatus
+from anyscale.service.models import (
+    ServiceConfig,
+    ServiceLogMode,
+    ServiceState,
+    ServiceStatus,
+)
 
 
 _SERVICE_SDK_SINGLETON_KEY = "service_sdk"
@@ -210,3 +215,47 @@ def wait(
         timeout_s=timeout_s,
         interval_s=_interval_s,
     )
+
+
+_CONTROLLER_LOGS_EXAMPLE = """
+import anyscale
+
+anyscale.service.controller_logs("my-service", canary=True)
+"""
+
+_CONTROLLER_LOGS_ARG_DOCSTRINGS = {
+    "name": "Name of the service.",
+    "cloud": "The Anyscale Cloud to run this workload on. If not provided, the organization default will be used (or, if running in a workspace, the cloud of the workspace).",
+    "project": "Named project to use for the service. If not provided, the default project for the cloud will be used (or, if running in a workspace, the project of the workspace).",
+    "canary": "Whether to show the logs of the canary version of the service. If not provided, the primary version logs will be shown.",
+    "mode": "The mode of log fetching to be used. Supported modes can be found in ServiceLogMode. If not provided, ServiceLogMode.TAIL will be used.",
+    "max_lines": "The number of log lines to be fetched. If not provided, 1000 lines will be fetched.",
+}
+
+
+# This is a private command that is not exposed to the user.
+@sdk_command(
+    _SERVICE_SDK_SINGLETON_KEY,
+    PrivateServiceSDK,
+    doc_py_example=_CONTROLLER_LOGS_EXAMPLE,
+    arg_docstrings=_CONTROLLER_LOGS_ARG_DOCSTRINGS,
+)
+def _controller_logs(
+    name: str,
+    *,
+    cloud: Optional[str] = None,
+    project: Optional[str] = None,
+    canary: bool = False,
+    mode: Union[str, ServiceLogMode] = ServiceLogMode.TAIL,
+    max_lines: int = 1000,
+    _sdk: PrivateServiceSDK,
+):
+    """Wait for a service to reach a target state."""
+    return _sdk.controller_logs(
+        name,
+        cloud=cloud,
+        project=project,
+        canary=canary,
+        mode=mode,
+        max_lines=max_lines,
+    )
