@@ -98,7 +98,7 @@ def _upload_file_to_google_cloud_storage(file: str, bucket: str, object_name: st
         raise click.ClickException(
             f"Failed to upload the working directory to Google Cloud Storage. Error {e!r}"
             "Please validate you have exported cloud credentials with the correct write permissions and the intended bucket exists in your Cloud Storage account. "
-            "If you do not desire to upload your working directory, please set your working directory to a public remote URI or remove the runtime_environment from you service yaml."
+            "If you do not desire to upload your working directory, please set your working directory to a public remote URI or remove the runtime_environment from your job or service yaml."
         ) from e
 
 
@@ -119,7 +119,7 @@ def _upload_file_to_s3(file: str, bucket: str, object_key: str):
         raise click.ClickException(
             f"Failed to upload the working directory to S3. Error {e!r}"
             "Please validate you have exported cloud credentials with the correct write permissions and the intended bucket exists in your S3 account. "
-            "If you do not desire to upload your working directory, please set your working directory to a public remote URI or remove the runtime_environment from you service yaml."
+            "If you do not desire to upload your working directory, please set your working directory to a public remote URI or remove the runtime_environment from your job or service yaml."
         ) from e
 
 
