@@ -2,7 +2,7 @@ from functools import partial
 import os
 import subprocess
 import tempfile
-from typing import cast, List, Optional, Tuple, Union
+from typing import cast, Dict, List, Optional, Tuple, Union
 
 from anyscale._private.workload.workload_sdk import WorkloadSDK
 from anyscale.client.openapi_client.models import (
@@ -10,9 +10,13 @@ from anyscale.client.openapi_client.models import (
     ExperimentalWorkspace,
 )
 from anyscale.client.openapi_client.models.session_state import SessionState
+from anyscale.client.openapi_client.models.workspace_dataplane_proxied_artifacts import (
+    WorkspaceDataplaneProxiedArtifacts,
+)
 from anyscale.utils.runtime_env import parse_requirements_file
 from anyscale.workspace.models import (
     UpdateWorkspaceConfig,
+    Workspace,
     WorkspaceConfig,
     WorkspaceState,
 )
@@ -217,6 +221,7 @@ class PrivateWorkspaceSDK(WorkloadSDK):
         workspace_model = self._resolve_to_workspace_model(
             id=id, name=name, cloud=cloud, project=project
         )
+
         status = self._get_workspace_status(workspace_model.id)
         return status
 
@@ -279,6 +284,13 @@ class PrivateWorkspaceSDK(WorkloadSDK):
                 f"Workspace '{workspace_id_or_name}' did not reach target state {state} within {timeout_s}s. Last seen state: {curr_state}."
             )
 
+    def _get_workspace_status(self, workspace_id: str) -> WorkspaceState:
+
+        cluster = self.client.get_workspace_cluster(workspace_id)
+        if not cluster:
+            raise ValueError(f"Workspace {workspace_id} cluster not found.")
+        return self._convert_cluster_state_to_workspace_state(cluster.state)
+
     def generate_ssh_config_file(
         self,
         *,
@@ -359,15 +371,6 @@ class PrivateWorkspaceSDK(WorkloadSDK):
         )
         return self.client.get_workspace_default_dir_name(workspace_model.id)
 
-    def _get_workspace_status(self, workspace_id: str) -> WorkspaceState:
-        workspace_session_state = self.client.get_workspace_status(workspace_id)
-        return cast(
-            WorkspaceState,
-            self._BACKEND_SESSION_STATE_TO_WORKSPACE_STATE.get(
-                workspace_session_state, WorkspaceState.UNKNOWN
-            ),
-        )
-
     def _run_rsync(
         self,
         *,
@@ -560,3 +563,95 @@ class PrivateWorkspaceSDK(WorkloadSDK):
             self._logger.info(f"Applied environment variables to workspace id: {id}")
 
         return id
+
+    def _convert_cluster_state_to_workspace_state(
+        self, state: SessionState
+    ) -> WorkspaceState:
+        return cast(
+            WorkspaceState,
+            self._BACKEND_SESSION_STATE_TO_WORKSPACE_STATE.get(
+                state, WorkspaceState.UNKNOWN
+            ),
+        )
+
+    def _convert_env_var_list_to_dict(
+        self, env_vars: Optional[List[str]]
+    ) -> Dict[str, str]:
+        if not env_vars:
+            return {}
+        return dict([env_var.split("=", 1) for env_var in env_vars])
+
+    def _convert_requirements_str_to_list(
+        self, requirements: Optional[str]
+    ) -> List[str]:
+        if not requirements:
+            return []
+        return [req for req in requirements.split("\n") if req]
+
+    def _transform_internal_to_external_workspace_model(
+        self, model: ExperimentalWorkspace
+    ) -> Workspace:
+        """Transforms an internal workspace model to a public-facing workspace model."""
+        cluster = self.client.get_workspace_cluster(model.id)
+        if not cluster:
+            raise ValueError(
+                f"Workspace cluster with ID '{model.cluster_id}' was not found."
+            )
+
+        workspace_status = self._convert_cluster_state_to_workspace_state(cluster.state)
+        idle_termination_minutes = cluster.idle_timeout
+
+        build_id = cluster.build_id
+        image_uri = self._image_sdk.get_image_uri_from_build_id(build_id)
+        if image_uri is None:
+            raise RuntimeError(f"Failed to get image URI for ID {build_id}.")
+        image_build = self._image_sdk.get_image_build(build_id)
+        if image_build is None:
+            raise RuntimeError(f"Failed to get image build for ID {build_id}.")
+
+        compute_config = self.get_user_facing_compute_config(model.compute_config_id)
+
+        cloud = self.client.get_cloud(cloud_id=model.cloud_id)
+        project = self.client.get_project(project_id=model.project_id)
+
+        workspace_dataplane_artifacts: WorkspaceDataplaneProxiedArtifacts = self.client.get_workspace_proxied_dataplane_artifacts(
+            workspace_id=model.id
+        )
+        env_vars_dict = self._convert_env_var_list_to_dict(
+            workspace_dataplane_artifacts.environment_variables
+        )
+        requirements = self._convert_requirements_str_to_list(
+            workspace_dataplane_artifacts.requirements
+        )
+
+        return Workspace(
+            id=model.id,
+            name=model.name,
+            config=WorkspaceConfig(
+                name=model.name,
+                compute_config=compute_config,
+                registry_login_secret=image_build.registry_login_secret,
+                image_uri=str(image_uri),
+                requirements=requirements if requirements else None,
+                idle_termination_minutes=idle_termination_minutes,
+                env_vars=env_vars_dict,
+                project=project.name if project else None,
+                cloud=cloud.name if cloud else None,
+            ),
+            state=workspace_status,
+        )
+
+    def get(
+        self,
+        *,
+        id: Optional[str] = None,  # noqa: A002
+        name: Optional[str] = None,
+        cloud: Optional[str] = None,
+        project: Optional[str] = None,
+    ) -> Workspace:  # noqa: A002
+        internal_workspace_model = self._resolve_to_workspace_model(
+            id=id, name=name, cloud=cloud, project=project
+        )
+        return self._transform_internal_to_external_workspace_model(
+            internal_workspace_model
+        )
