@@ -2,13 +2,11 @@ import json
 import os
 from pathlib import Path
 import tempfile
-import time
 from types import SimpleNamespace
-from typing import Any, Dict, List, Optional, Tuple, Type
+from typing import Any, Dict, List, Optional
 from unittest.mock import ANY, call, MagicMock, Mock, mock_open, patch
 
-import aiohttp
-from asynctest import CoroutineMock, patch as async_patch
+from asynctest import CoroutineMock
 import click
 import pytest
 import yaml
@@ -18,21 +16,20 @@ from anyscale.client.openapi_client.models.create_internal_production_job import
     CreateInternalProductionJob,
 )
 from anyscale.client.openapi_client.models.ha_job_states import HaJobStates
-from anyscale.client.openapi_client.models.job_queue_config import JobQueueConfig
 from anyscale.client.openapi_client.models.production_job_config import (
     ProductionJobConfig,
 )
 from anyscale.controllers.job_controller import (
     JobController,
-    LogProvider,
     LogsLogger,
-    LokiLogProvider,
 )
 from anyscale.models.job_model import _working_dir_is_remote_uri, JobConfig
 from anyscale.sdk.anyscale_client.models.compute_template import ComputeTemplate
-from anyscale.shared_anyscale_utils.test_util import MockAsyncContextManagerReturnValue
 from anyscale.util import PROJECT_NAME_ENV_VAR
 from anyscale.utils.runtime_env import is_dir_remote_uri
+from frontend.cli.anyscale.client.openapi_client.models.create_job_queue_config import (
+    CreateJobQueueConfig,
+)
 
 
 CONDA_DICT = {"dependencies": ["pip", {"pip": ["pip-install-test==0.5"]}]}
@@ -143,7 +140,6 @@ def test_config_validation(add_extra_field, mock_auth_api_client):
         "project_id": project_id,
         "build_id": build_id,
         "compute_config_id": compute_config_id,
-        "compute_config_version": 2,
     }
     if add_extra_field:
         extra_field_value = "*****"
@@ -305,7 +301,6 @@ def test_submit_job(
         cluster_compute_id=compute_template_test_data.id,
         cluster_compute=config_dict.get("compute_config"),
         cloud=config_dict.get("cloud"),
-        cluster_compute_version=config_dict.get("compute_config_version"),
     )
 
     if config_project_id:
@@ -317,7 +312,7 @@ def test_submit_job(
 
     if "job_queue_config" in config_dict:
         job_queue_config_dict = config_dict["job_queue_config"]
-        expected_job_queue_config = JobQueueConfig(**job_queue_config_dict)
+        expected_job_queue_config = CreateJobQueueConfig(**job_queue_config_dict)
     else:
         expected_job_queue_config = None
 
@@ -328,11 +323,9 @@ def test_submit_job(
             project_id=final_project_id,
             workspace_id=None,
             config=ProductionJobConfig(  # noqa: PIE804
-                **{
-                    "entrypoint": "mock_entrypoint",
-                    "build_id": "mock_build_id",
-                    "compute_config_id": compute_template_test_data.id,
-                }
+                entrypoint="mock_entrypoint",
+                build_id="mock_build_id",
+                compute_config_id=compute_template_test_data.id,
             ),
             job_queue_config=expected_job_queue_config,
         )
@@ -343,9 +336,7 @@ def test_submit_job(
     if "compute_config" in config_dict:
         compute_config = config_dict["compute_config"]
         if isinstance(compute_config, str):
-            mock_get_cluster_compute_from_name.assert_called_with(
-                compute_config, version=None
-            )
+            mock_get_cluster_compute_from_name.assert_called_with(compute_config)
         elif isinstance(compute_config, dict):
             mock_register_compute_template.assert_called_once_with(compute_config)
     elif "cloud" in config_dict:
@@ -848,7 +839,7 @@ class TestComputeConfig:
         assert jc.compute_config_id == "mock_existing_compute_config_id"
         mock_get_default_cluster_compute.assert_not_called()
         mock_get_cluster_compute_from_name.assert_called_once_with(
-            "mock_existing_compute_config_name", version=None
+            "mock_existing_compute_config_name"
         )
         mock_register_compute_template.assert_not_called()
         mock_get_parent_cloud_id_and_name_of_project.assert_not_called()
@@ -954,75 +945,6 @@ def test_validate_project_id_field(
                 assert job_config.project_id == project_id
 
 
-def fake_log_provider(mode: str) -> Type[LogProvider]:
-    class FakeLogProvider(LogProvider):
-        def __init__(self, *args, **kwargs) -> None:
-            self.constructed_at = int(time.time() * 1e9)
-            self.page = -1
-            self.query_count = 0
-
-        def close(self):
-            pass
-
-        async def query(  # noqa: PLR0911
-            self, start_timestamp_ns: int, end_timestamp_ns: int
-        ) -> List[Tuple[int, str]]:
-            # For typing
-            empty_list: List[Tuple[int, str]] = []
-
-            if mode == "empty":
-                return empty_list
-            if mode == "single":
-                if start_timestamp_ns > self.constructed_at:
-                    return []
-                return [(start_timestamp_ns, "start"), (self.constructed_at, "end")]
-            if mode == "paginate":
-                self.page += 1
-                return [
-                    [(start_timestamp_ns, "entry-1")],
-                    [(start_timestamp_ns + 1, "entry-2")],
-                    empty_list,
-                ][self.page]
-            if mode == "follow":
-                self.page += 1
-                return [
-                    # simulate no log
-                    empty_list,
-                    empty_list,
-                    [(start_timestamp_ns, "finally")],
-                ][self.page]
-            if mode == "flush_success":
-                self.page += 1
-                return (
-                    [
-                        # simulate no log
-                        empty_list,
-                        empty_list,
-                        [(start_timestamp_ns, "finally")],
-                        empty_list,
-                        # Simulate 30 steps of empty logs
-                    ]
-                    + [empty_list for _ in range(30)]
-                )[self.page]
-            if mode == "wait_for_running":
-                self.page += 1
-                return (
-                    [
-                        # simulate no log
-                        empty_list,
-                        empty_list,
-                        [(start_timestamp_ns, "finally")],
-                        empty_list,
-                        # Simulate 30 steps of empty logs
-                    ]
-                    + [empty_list for _ in range(30)]
-                )[self.page]
-
-            raise Exception("unreachable")
-
-    return FakeLogProvider
-
-
 def test_logs_streaming(mock_auth_api_client) -> None:
     job_controller = JobController()
     prod_job_id = "prodjob_123"
@@ -1067,6 +989,7 @@ def test_logs_streaming(mock_auth_api_client) -> None:
                 remove_escape_chars=False,
                 next_page_token=None,
                 cluster_journal_events_start_line=0,
+                no_cluster_journal_events=False,
             ),
             call(
                 ANY,
@@ -1075,6 +998,7 @@ def test_logs_streaming(mock_auth_api_client) -> None:
                 remove_escape_chars=False,
                 next_page_token="next_token",
                 cluster_journal_events_start_line=10,
+                no_cluster_journal_events=False,
             ),
             call(
                 ANY,
@@ -1083,6 +1007,7 @@ def test_logs_streaming(mock_auth_api_client) -> None:
                 remove_escape_chars=False,
                 next_page_token="next_token_2",
                 cluster_journal_events_start_line=10,
+                no_cluster_journal_events=False,
             ),
             call(
                 ANY,
@@ -1091,6 +1016,7 @@ def test_logs_streaming(mock_auth_api_client) -> None:
                 remove_escape_chars=False,
                 next_page_token="next_token_3",
                 cluster_journal_events_start_line=10,
+                no_cluster_journal_events=False,
             ),
             call(
                 ANY,
@@ -1099,6 +1025,7 @@ def test_logs_streaming(mock_auth_api_client) -> None:
                 remove_escape_chars=False,
                 next_page_token="next_token_3",
                 cluster_journal_events_start_line=10,
+                no_cluster_journal_events=False,
             ),
         ]
     )
@@ -1304,71 +1231,3 @@ def test_override_runtime_env_config_and_infer_project_id(mock_auth_api_client):
                 ),
             )
         )
-
-
-async def test_loki_log_provider():
-    tenant_id = "fake_tenant_id"
-    token = "fake_token"
-    mocked_response = MockAsyncContextManagerReturnValue()
-    mocked_response.json = CoroutineMock(
-        return_value={
-            "status": "success",
-            "data": {
-                "resultType": "streams",
-                "result": [
-                    {
-                        "metric": {"level": "info"},
-                        "values": [[1, "log1"], [3, "log3"], [4, "log4"],],
-                    },
-                    {
-                        "metric": {"level": "warn"},
-                        "values": [[2, "log2"], [6, "log6"], [5, "log5"],],
-                    },
-                ],
-            },
-        }
-    )
-    mocked_session = MagicMock()
-    mocked_session.get.return_value = mocked_response
-    mocked_session.close = CoroutineMock(return_value=None)
-    with async_patch.object(
-        aiohttp, aiohttp.ClientSession.__name__, return_value=mocked_session,
-    ):
-        async with LokiLogProvider(
-            dns_name="fake_dns_name",
-            token=token,
-            query="fake_query",
-            limit=100,
-            tenant_id=tenant_id,
-            direction="backward",
-        ) as loki_log_provider:
-            logs = await loki_log_provider.query(
-                start_timestamp_ns=123, end_timestamp_ns=456
-            )
-            expected_logs = [
-                (1, "log1"),
-                (3, "log3"),
-                (4, "log4"),
-                (2, "log2"),
-                (6, "log6"),
-                (5, "log5"),
-            ]
-            assert logs == expected_logs
-
-        # Ensure that the headers are set correctly
-        expected_headers = {
-            "X-Scope-OrgID": tenant_id,
-            "Authorization": f"Bearer {token}",
-        }
-        mocked_session.get.assert_called_once_with(
-            "https://fake_dns_name/loki/api/v1/query_range",
-            headers=expected_headers,
-            params={
-                "query": "fake_query",
-                "limit": 100,
-                "start": 123,
-                "end": 456,
-                "direction": "backward",
-            },
-            timeout=60,
-        )
