@@ -16,6 +16,9 @@ def test_list_machines(mock_auth_api_client: str) -> None:
                 machine_id="m-123",
                 hostname="dummy",
                 machine_shape="lambda-a100-80g",
+                num_cpus=2,
+                num_gpus=1,
+                memory_bytes=1000000000,
                 connection_state=MachineConnectionState.CONNECTED,
                 allocation_state=MachineAllocationState.AVAILABLE,
             )
@@ -29,7 +32,5 @@ def test_list_machines(mock_auth_api_client: str) -> None:
     machine_controller.api_client.list_machines_api_v2_machines_get = Mock(
         return_value=api_response
     )
-    output = machine_controller.list_machines(
-        cloud_id=None, cloud=None, machine_pool_name="pool1"
-    )
+    output = machine_controller.list_machines(machine_pool_name="pool1")
     assert output == response
