@@ -92,3 +92,59 @@ def test_validate_api_client_auth() -> None:
     )
     with pytest.raises(click.ClickException):
         auth_api_client._validate_api_client_auth()
+
+
+def test_warn_credential_file_permissions():
+    """
+    Test if logger warns when credentials file permissions are too open
+    """
+    with patch.multiple(
+        "os.path",
+        expanduser=Mock(return_value="/home/usr0/.anyscale/credentials.json"),
+        exists=Mock(return_value=True),
+    ), patch("os.stat", Mock()):
+        mock_log_warning = Mock()
+
+        nowarn_modes = [0o600, 0o700, 0o400]
+        for mode in nowarn_modes:
+            with patch("stat.S_IMODE", Mock(return_value=mode)), patch(
+                "anyscale.cli_logger.BlockLogger.warning", mock_log_warning
+            ):
+                auth = AuthenticationBlock(cli_token="", validate_credentials=False)
+                auth._warn_credential_file_permissions(
+                    "/home/usr0/.anyscale/credentials.json"
+                )
+            mock_log_warning.assert_not_called()
+            mock_log_warning.reset_mock()
+
+        warn_modes = [0o644, 0o777, 0o640, 0o770]
+        for mode in warn_modes:
+            with patch("stat.S_IMODE", Mock(return_value=mode)), patch(
+                "anyscale.cli_logger.BlockLogger.warning", mock_log_warning
+            ):
+                auth = AuthenticationBlock(cli_token="", validate_credentials=False)
+                auth._warn_credential_file_permissions(
+                    "/home/usr0/.anyscale/credentials.json"
+                )
+            mock_log_warning.assert_called()
+            mock_log_warning.reset_mock()
+
+
+def test_warn_credential_file_permissions_dont_on_windows():
+    """
+    Test that no warning is printed on Windows
+    """
+    mock_log_warning = Mock()
+    with patch.multiple(
+        "os.path",
+        expanduser=Mock(return_value="/home/usr0/.anyscale/credentials.json"),
+        exists=Mock(return_value=True),
+    ), patch("os.stat", Mock()), patch(
+        "anyscale.cli_logger.BlockLogger.warning", mock_log_warning
+    ), patch(
+        "platform.system", Mock(return_value="Windows")
+    ):
+        auth = AuthenticationBlock(cli_token="", validate_credentials=False)
+        auth._warn_credential_file_permissions("/home/usr0/.anyscale/credentials.json")
+
+    mock_log_warning.assert_not_called()
