@@ -4,7 +4,7 @@ from pathlib import Path
 import re
 import sys
 from tempfile import NamedTemporaryFile
-from typing import Any, Callable, List
+from typing import Any, Callable, List, Optional
 from unittest.mock import MagicMock, Mock, patch
 
 import click
@@ -27,8 +27,8 @@ from anyscale.gcp_verification import (
     _check_bucket_region,
     _firewall_rules_from_proto_resp,
     _gcp_subnet_has_enough_capacity,
+    _get_proxy_only_subnet_in_vpc,
     _verify_service_account_on_bucket,
-    _vpc_has_proxy_only_subnet,
     GCPLogger,
     verify_cloud_storage,
     verify_filestore,
@@ -176,15 +176,13 @@ def test_gcp_subnet_has_enough_capacity(cidr: str, result: bool, log: str, capsy
         ),
     ],
 )
-def test_vpc_has_proxy_only_subnet(setup_mock_server, responses, expected):
+def test_get_proxy_only_subnet_in_vpc(setup_mock_server, responses, expected):
     factory, tracker = setup_mock_server
     tracker.reset(responses=responses)
     assert (
-        _vpc_has_proxy_only_subnet(
-            factory, "myproject", "us-central1", Mock(self_link="myvpc")
-        )
-        == expected
-    )
+        _get_proxy_only_subnet_in_vpc(factory, "myproject", "us-central1", "myvpc")
+        is not None
+    ) == expected
     assert len(tracker.seen_requests) == 1
 
 
@@ -416,15 +414,17 @@ def test_verify_gcp_access_service_account_get_iam_policy_error(setup_mock_serve
 
 
 @pytest.mark.parametrize(
-    ("responses", "expected_result", "output"),
+    ("use_shared_vpc", "responses", "expected_result", "output"),
     [
         pytest.param(
+            False,
             {".*": [("404 Not Found", None), ("404 Not Found", None)]},
             False,
             re.compile(".*"),
             id="Neither Exist",
         ),
         pytest.param(
+            False,
             {
                 ".*": [
                     ("200 OK", "global_firewall.json"),
@@ -436,6 +436,19 @@ def test_verify_gcp_access_service_account_get_iam_policy_error(setup_mock_serve
             id="GlobalFirewall",
         ),
         pytest.param(
+            True,
+            {
+                ".*": [
+                    ("200 OK", "global_firewall.json"),
+                    ("200 OK", "subnetworks.json"),
+                ],
+            },
+            True,
+            re.compile(".*"),
+            id="GlobalFirewall-sharedvpc",
+        ),
+        pytest.param(
+            False,
             {
                 ".*": [
                     ("404 Not Found", None),
@@ -448,6 +461,7 @@ def test_verify_gcp_access_service_account_get_iam_policy_error(setup_mock_serve
             id="RegionalFirewall",
         ),
         pytest.param(
+            False,
             {".*": [("200 OK", "global_firewall_wrong_vpc.json")],},
             False,
             re.compile(".*is not associated with the VPC.*"),
@@ -456,7 +470,12 @@ def test_verify_gcp_access_service_account_get_iam_policy_error(setup_mock_serve
     ],
 )
 def test_verify_firewall_policy(
-    setup_mock_server, responses, expected_result: bool, output: re.Pattern, capsys
+    setup_mock_server,
+    responses,
+    use_shared_vpc: bool,
+    expected_result: bool,
+    output: re.Pattern,
+    capsys,
 ):
     factory, tracker = setup_mock_server
     tracker.reset(responses=responses)
@@ -467,6 +486,8 @@ def test_verify_firewall_policy(
             generate_gcp_cloud_mock_resources(),
             _MOCK_GCP_PROJECT_ID,
             _MOCK_GCP_CLOUD_REGION,
+            use_shared_vpc,
+            False,
             GCPLogger(CloudSetupLogger(), "project", Mock()),
         )
         == expected_result
@@ -475,6 +496,126 @@ def test_verify_firewall_policy(
     assert output.search(stderr), f"Missing output in {stderr}"
 
 
+@pytest.mark.parametrize(
+    ("responses", "expected_result"),
+    [
+        pytest.param(
+            {
+                ".*": [
+                    ("200 OK", "global_firewall_without_service_rule.json"),
+                    ("200 OK", "subnetworks.json"),
+                ],
+            },
+            False,
+            id="GlobalFirewall-sharedvpc",
+        ),
+        pytest.param(
+            {
+                ".*": [
+                    ("200 OK", "global_firewall.json"),
+                    ("200 OK", "subnetworks.json"),
+                ],
+            },
+            True,
+            id="GlobalFirewall",
+        ),
+    ],
+)
+def test_verify_firewall_policy_rule_for_shared_vpc(
+    setup_mock_server, responses, expected_result: bool, capsys,
+):
+    factory, tracker = setup_mock_server
+    tracker.reset(responses=responses)
+
+    assert (
+        verify_firewall_policy(
+            factory,
+            generate_gcp_cloud_mock_resources(),
+            _MOCK_GCP_PROJECT_ID,
+            _MOCK_GCP_CLOUD_REGION,
+            True,
+            False,
+            GCPLogger(CloudSetupLogger(), "project", Mock()),
+        )
+        is True
+    )
+    _, stderr = capsys.readouterr()
+    print(stderr)
+    assert ("required for Anyscale services" not in stderr) == expected_result
+
+
+@pytest.mark.parametrize(
+    ("responses", "has_subnet", "expected_warning"),
+    [
+        pytest.param(
+            {
+                ".*": [
+                    ("200 OK", "global_firewall_with_service_rule.json"),
+                    ("200 OK", "subnetworks.json"),
+                ],
+            },
+            False,
+            "Could not find a subnet with purpose",
+            id="has-subnet-no-rule",
+        ),
+        pytest.param(
+            {
+                ".*": [
+                    ("200 OK", "global_firewall_with_service_rule.json"),
+                    ("200 OK", "subnetworks.json"),
+                ],
+            },
+            True,
+            "does not allow inbound access from the proxy-only subnet",
+            id="has-subnet-no-rule",
+        ),
+        pytest.param(
+            {
+                ".*": [
+                    ("200 OK", "global_firewall_with_private_service_rule.json"),
+                    ("200 OK", "subnetworks.json"),
+                ],
+            },
+            True,
+            None,
+            id="has-subnet-no-rule",
+        ),
+    ],
+)
+def test_verify_firewall_policy_rule_for_private_services_on_shared_vpc(
+    setup_mock_server,
+    responses,
+    expected_warning: Optional[str],
+    has_subnet: bool,
+    capsys,
+):
+    factory, tracker = setup_mock_server
+    tracker.reset(responses=responses)
+
+    # CIDR is rom the global_firewall_with_private_service_rule.json file
+    mock_subnet = Mock(ip_cidr_range="10.100.0.0/20") if has_subnet else None
+
+    with patch.multiple(
+        "anyscale.gcp_verification",
+        _get_proxy_only_subnet_in_vpc=Mock(return_value=mock_subnet),
+    ):
+        assert (
+            verify_firewall_policy(
+                factory,
+                generate_gcp_cloud_mock_resources(),
+                _MOCK_GCP_PROJECT_ID,
+                _MOCK_GCP_CLOUD_REGION,
+                True,
+                True,
+                GCPLogger(CloudSetupLogger(), "project", Mock()),
+            )
+            is True
+        )
+    _, stderr = capsys.readouterr()
+    if expected_warning:
+        assert expected_warning in stderr
+
+
 @pytest.mark.parametrize(
     ("proto", "rule"),
     [
@@ -730,7 +871,7 @@ def test_verify_memorystore(
 
 
 @patch.multiple(
-    "anyscale.gcp_verification", ANYSCALE_HOST="https://console.anyscale.com"
+    "anyscale.gcp_verification", ANYSCALE_CORS_ORIGIN="https://console.anyscale.com"
 )
 @pytest.mark.parametrize(
     ("update_fn", "expected_warn"),
