@@ -115,6 +115,19 @@ class TestImageURI:
                 "anyscale/image/cluser_env_name:3",
                 id="non-byod-build",
             ),
+            pytest.param(
+                Mock(
+                    is_byod=False,
+                    config_json=Mock(),
+                    containerfile=None,
+                    cluster_environment_id="DEFAULT_APP_CONFIG_ID_2.8.1_py39",
+                    docker_image_name="anyscale/ray:2.8.1-py39",
+                    revision=1,
+                ),
+                False,
+                "anyscale/ray:2.8.1-py39",
+                id="default_build",
+            ),
         ],
     )
     def test_from_cluster_env_build(
@@ -132,3 +145,15 @@ class TestImageURI:
             ).image_uri
             == expected_image_uri
         )
+
+    @pytest.mark.parametrize(
+        ("image_uri", "expected"),
+        [
+            ("docker.io/library/ubuntu:latest", False),
+            ("anyscale/image/cluser_env_name:3", False),
+            ("anyscale/ray:2.22.0-slim-py39-cu121", True),
+            ("anyscale/ray-ml:2.22.0-cu121", True),
+        ],
+    )
+    def test_is_default_image(self, image_uri: str, expected: bool):
+        assert ImageURI.from_str(image_uri).is_default_image() == expected
