@@ -374,6 +374,63 @@ class TestSubmit:
                 MINIMAL_CONFIG_PATH, name="test-name"
             )
 
+    def test_override_env_vars(self, fake_job_sdk, mock_job_controller):
+        runner = CliRunner()
+
+        expected_base_job_config = JobConfig(
+            name="test-name-from-file",
+            entrypoint="python test.py",
+            image_uri="docker.io/library/test:latest",
+            compute_config="test-compute-config",
+            working_dir="test-working-dir",
+            env_vars={"ENV_KEY": "ENV_VAL"},
+            excludes=["test"],
+            requirements=["pip-install-test"],
+            max_retries=5,
+            timeout_s=60,
+        )
+
+        # No overrides.
+        result = runner.invoke(submit, ["-f", FULL_CONFIG_PATH])
+        assert result.exit_code == 0
+        assert fake_job_sdk.submitted_config == expected_base_job_config
+
+        # Override existing env var.
+        result = runner.invoke(
+            submit, ["-f", FULL_CONFIG_PATH, "--env", "ENV_KEY=UPDATED_ENV_VAL"]
+        )
+        assert result.exit_code == 0
+        assert fake_job_sdk.submitted_config == expected_base_job_config.options(
+            env_vars={"ENV_KEY": "UPDATED_ENV_VAL"},
+        )
+
+        # Add new env var (existing shouldn't be touched).
+        result = runner.invoke(
+            submit, ["-f", FULL_CONFIG_PATH, "--env", "NEW_ENV_KEY=NEW_ENV_VAL"]
+        )
+        assert result.exit_code == 0
+        assert fake_job_sdk.submitted_config == expected_base_job_config.options(
+            env_vars={"ENV_KEY": "ENV_VAL", "NEW_ENV_KEY": "NEW_ENV_VAL"},
+        )
+
+        # Set env var in a config that doesn't have any.
+        result = runner.invoke(
+            submit, ["-f", MINIMAL_CONFIG_PATH, "--env", "ENV_KEY=ENV_VAL"]
+        )
+        assert result.exit_code == 0
+        assert fake_job_sdk.submitted_config == JobConfig(
+            entrypoint="python test.py", env_vars={"ENV_KEY": "ENV_VAL"},
+        )
+
+        # Set env var in an inlined entrypoint.
+        result = runner.invoke(
+            submit, ["--env", "ENV_KEY=ENV_VAL", "--", "python", "main.py"]
+        )
+        assert result.exit_code == 0
+        assert fake_job_sdk.submitted_config == JobConfig(
+            entrypoint="python main.py", env_vars={"ENV_KEY": "ENV_VAL"},
+        )
+
     @pytest.mark.parametrize("inlined_entrypoint", [False, True])
     def test_no_wait_by_default(
         self, fake_job_sdk, mock_job_controller, inlined_entrypoint: bool
