@@ -327,6 +327,7 @@ class TestDeploy:
             image_uri="docker.io/library/test:latest",
             compute_config=inline_compute_config,
             working_dir="test-working-dir",
+            env_vars={"ENV_KEY": "ENV_VAL"},
             excludes=["test"],
             requirements=["pip-install-test"],
             query_auth_token_enabled=False,
@@ -349,6 +350,7 @@ class TestDeploy:
             image_uri="docker.io/library/test:latest",
             compute_config=inline_compute_config,
             working_dir="test-working-dir",
+            env_vars={"ENV_KEY": "ENV_VAL"},
             excludes=["test"],
             requirements=["pip-install-test"],
             query_auth_token_enabled=False,
@@ -380,6 +382,7 @@ class TestDeploy:
             registry_login_secret="secret-name",
             compute_config=inline_compute_config,
             working_dir="test-working-dir",
+            env_vars={"ENV_KEY": "ENV_VAL"},
             excludes=["test"],
             requirements=["pip-install-test"],
             query_auth_token_enabled=False,
@@ -403,6 +406,7 @@ class TestDeploy:
             image_uri="docker.io/library/test:latest",
             compute_config="override-compute-config",
             working_dir="test-working-dir",
+            env_vars={"ENV_KEY": "ENV_VAL"},
             excludes=["test"],
             requirements=["pip-install-test"],
             query_auth_token_enabled=False,
@@ -425,6 +429,7 @@ class TestDeploy:
             image_uri="docker.io/library/test:latest",
             compute_config=inline_compute_config,
             working_dir="override-working-dir",
+            env_vars={"ENV_KEY": "ENV_VAL"},
             excludes=["test"],
             requirements=["pip-install-test"],
             query_auth_token_enabled=False,
@@ -448,6 +453,7 @@ class TestDeploy:
             image_uri="docker.io/library/test:latest",
             compute_config=inline_compute_config,
             working_dir="test-working-dir",
+            env_vars={"ENV_KEY": "ENV_VAL"},
             excludes=["test"],
             requirements=MULTI_LINE_REQUIREMENTS_PATH,
             query_auth_token_enabled=False,
@@ -457,19 +463,10 @@ class TestDeploy:
         )
         assert fake_service_sdk.deployed_config == expected_config
 
-        # Override environment variables.
+        # Override existing environment variable.
         result = runner.invoke(
-            deploy,
-            [
-                "-f",
-                FULL_CONFIG_PATH,
-                "--env",
-                "FOO=BAR_override",
-                "--env",
-                "FOO2=BAR2",
-            ],
+            deploy, ["-f", FULL_CONFIG_PATH, "--env", "ENV_KEY=UPDATED_ENV_VAL",],
         )
-        print(result.stdout)
         assert result.exit_code == 0
         assert fake_service_sdk.deployed_config is not None
         expected_config = ServiceConfig(
@@ -478,13 +475,46 @@ class TestDeploy:
             image_uri="docker.io/library/test:latest",
             compute_config=inline_compute_config,
             working_dir="test-working-dir",
+            env_vars={"ENV_KEY": "UPDATED_ENV_VAL"},
             excludes=["test"],
             requirements=["pip-install-test"],
             query_auth_token_enabled=False,
             http_options={"request_timeout_s": 10.0},
             grpc_options={"grpc_servicer_functions": ["hello.world"]},
             logging_config={"log_level": "DEBUG"},
-            env_vars={"FOO": "BAR_override", "FOO2": "BAR2"},
+        )
+        assert fake_service_sdk.deployed_config == expected_config
+
+        # Add additional environment variable.
+        result = runner.invoke(
+            deploy, ["-f", FULL_CONFIG_PATH, "--env", "NEW_ENV_KEY=NEW_ENV_VAL",],
+        )
+        assert result.exit_code == 0
+        assert fake_service_sdk.deployed_config is not None
+        expected_config = ServiceConfig(
+            applications=[{"import_path": "main:app"}],
+            name="test-name-from-file",
+            image_uri="docker.io/library/test:latest",
+            compute_config=inline_compute_config,
+            working_dir="test-working-dir",
+            env_vars={"ENV_KEY": "ENV_VAL", "NEW_ENV_KEY": "NEW_ENV_VAL"},
+            excludes=["test"],
+            requirements=["pip-install-test"],
+            query_auth_token_enabled=False,
+            http_options={"request_timeout_s": 10.0},
+            grpc_options={"grpc_servicer_functions": ["hello.world"]},
+            logging_config={"log_level": "DEBUG"},
+        )
+        assert fake_service_sdk.deployed_config == expected_config
+
+        # Set environment variable in a config that doesn't have any.
+        result = runner.invoke(
+            deploy, ["-f", MINIMAL_CONFIG_PATH, "--env", "ENV_KEY=ENV_VAL",],
+        )
+        assert result.exit_code == 0
+        assert fake_service_sdk.deployed_config is not None
+        expected_config = ServiceConfig(
+            applications=[{"import_path": "main:app"}], env_vars={"ENV_KEY": "ENV_VAL"},
         )
         assert fake_service_sdk.deployed_config == expected_config
 
