@@ -2549,3 +2549,85 @@ class TestWait:
             "Service 'test-service-name' reached target state, exiting" in info_log
             for info_log in logger.info_messages
         )
+
+
+class TestControllerLogs:
+    def test_controller_logs(
+        self,
+        service_sdk_with_fakes: Tuple[
+            ServiceSDK, FakeAnyscaleClient, TestLogger, FakeTimer
+        ],
+    ):
+        sdk, fake_client, _, _ = service_sdk_with_fakes
+
+        service_id = "test-service-id"
+        name = "test-service-name"
+        fake_client.update_service(
+            ServiceModel(
+                id=service_id,
+                name=name,
+                local_vars_configuration=OPENAPI_NO_VALIDATION,
+                primary_version=ServiceVersionStatus(
+                    id="primary",
+                    state=ServiceVersionState.RUNNING,
+                    weight=100,
+                    config=ServiceConfig(
+                        name=TEST_SERVICE_NAME,
+                        applications=TEST_APPLICATIONS,
+                        image_uri=TEST_IMAGE_URI.image_uri,
+                        compute_config=TEST_COMPUTE_CONFIG_NAME + ":1",
+                        query_auth_token_enabled=False,
+                    ),
+                ),
+            )
+        )
+
+        # Get logs of primary version
+        fake_client.add_controller_logs("primary", "primary-version-logs")
+        assert sdk.controller_logs("test-service-name") == "primary-version-logs"
+
+        # Getting canary version logs should fail
+        with pytest.raises(
+            ValueError,
+            match=f"Service '{name}' is not currently rolling out. There is no canary version.",
+        ):
+            sdk.controller_logs("test-service-name", canary=True)
+
+        # Add canary version
+        fake_client.update_service(
+            ServiceModel(
+                id=service_id,
+                name=name,
+                local_vars_configuration=OPENAPI_NO_VALIDATION,
+                primary_version=ServiceVersionStatus(
+                    id="primary",
+                    state=ServiceVersionState.RUNNING,
+                    weight=50,
+                    config=ServiceConfig(
+                        name=TEST_SERVICE_NAME,
+                        applications=TEST_APPLICATIONS,
+                        image_uri=TEST_IMAGE_URI.image_uri,
+                        compute_config=TEST_COMPUTE_CONFIG_NAME + ":1",
+                        query_auth_token_enabled=False,
+                    ),
+                ),
+                canary_version=ServiceVersionStatus(
+                    id="canary",
+                    state=ServiceVersionState.RUNNING,
+                    weight=50,
+                    config=ServiceConfig(
+                        name=TEST_SERVICE_NAME,
+                        applications=TEST_APPLICATIONS,
+                        image_uri=TEST_IMAGE_URI.image_uri,
+                        compute_config=TEST_COMPUTE_CONFIG_NAME + ":1",
+                        query_auth_token_enabled=False,
+                    ),
+                ),
+            )
+        )
+        fake_client.add_controller_logs("canary", "canary-version-logs")
+        assert (
+            sdk.controller_logs("test-service-name", canary=True)
+            == "canary-version-logs"
+        )
+        assert sdk.controller_logs("test-service-name") == "primary-version-logs"
