@@ -1282,3 +1282,62 @@ class TestUpdate:
         assert fake_client._workspaces_env_vars[updated_workspace.id] == {
             "key": "value"
         }
+
+
+class TestGet:
+    def test_missing_arg(
+        self,
+        workspace_sdk_with_fakes: Tuple[
+            WorkspaceSDK, FakeAnyscaleClient, TestLogger, FakeTimer
+        ],
+    ):
+        sdk, fake_client, _, _ = workspace_sdk_with_fakes
+
+        with pytest.raises(ValueError, match="One of 'name' or 'id' must be provided."):
+            sdk.get(name=None, id=None, cloud=None, project=None)
+
+    def test_basic_with_id(
+        self,
+        workspace_sdk_with_fakes: Tuple[
+            WorkspaceSDK, FakeAnyscaleClient, TestLogger, FakeTimer
+        ],
+    ):
+        sdk, fake_client, _, _ = workspace_sdk_with_fakes
+
+        # create first
+        workspace_id = sdk.create(config=WorkspaceConfig(name="test_workspace"))
+        assert workspace_id is not None
+
+        workspace = sdk.get(id=workspace_id)
+        assert workspace is not None
+        assert workspace.name == "test_workspace"
+
+    def test_basic_with_name(
+        self,
+        workspace_sdk_with_fakes: Tuple[
+            WorkspaceSDK, FakeAnyscaleClient, TestLogger, FakeTimer
+        ],
+    ):
+        sdk, fake_client, _, _ = workspace_sdk_with_fakes
+
+        # create first
+        workspace_id = sdk.create(config=WorkspaceConfig(name="test_workspace"))
+        assert workspace_id is not None
+
+        workspace = sdk.get(name="test_workspace")
+        assert workspace is not None
+        assert workspace.name == "test_workspace"
+
+    def test_not_found(
+        self,
+        workspace_sdk_with_fakes: Tuple[
+            WorkspaceSDK, FakeAnyscaleClient, TestLogger, FakeTimer
+        ],
+    ):
+        sdk, fake_client, _, _ = workspace_sdk_with_fakes
+
+        name = "test_workspace"
+        with pytest.raises(
+            ValueError, match=f"Workspace with name '{name}' was not found."
+        ):
+            sdk.get(name=name)
